#
# spec file for package jabberd
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           jabberd
BuildRequires:  openssl-devel postgresql-devel sqlite-devel
BuildRequires:  db-devel libidn-devel
BuildRequires:  cyrus-sasl-devel openldap2-devel
BuildRequires:  dos2unix pam-devel udns
%if 0%{?suse_version} > 1020
BuildRequires:  libexpat-devel
%else
BuildRequires:  expat
%endif
%if 0%{?suse_version} >= 1010
BuildRequires:  mysql-devel
%define mysql 1
%else
%define mysql 0
%endif
Version:        2.2.11
Release:        1.2
Url:            http://jabberd.jabberstudio.org/
Group:          Productivity/Networking/Other
License:        GPL v2 or later
Summary:        Jabber Open Source Server
Source:         %{name}-%{version}.tar.bz2
Source1:        jabberd.init
Source2:        jabberd.pam
Source3:        jabberd-rpmlintrc
Patch1:         jabberd-sasl.patch
Patch2:         jabberd-main.patch
Patch5:         jabberd-etc.patch
Patch9:         0001-Use-OpenSSL-functions-for-base64-en-decoding-when-av.patch
# Needed for init script,
Requires:       net-tools
PreReq:         pwdutils
PreReq:         %insserv_prereq
AutoReqProv:    on
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Jabber open source server.



Authors:
--------
    Ryan Eatmon <reatmon@jabber.org>
    Jeremie Miller <jeremie@jabber.org>
    Thomas Muldowney <temas@jabber.org>
    Robert Norris <rob@cataclysm.cx>
    Casey Crabb <crabbkw@nafai.dyndns.org>
    Matthias Wimmer <m@tthias.net>
    William Uther <willu@cse.unsw.edu.au>
    Wim Lewis <wiml@hhhh.org>
    Mike Prince <mike@mikeprince.com>
    Jamin W. Collins <jcollins@asgardsrealm.net>
    Jacek Konieczny <jajcus@bnet.pl>
    maqi <maqi@jabberstudio.org>
    Karsten Huneycutt <kph@duke.edu>
    Shane DeRidder <shane@silicondairy.net>
    Magnus Henoch <mange@freemail.hu>
    Dudley Carr <dudley@cs.stanford.edu>
    Patrick Bihan-Faou <patrick@mindstep.com>
    Peter Hinz <peter@cerebus.co.za>
    Karsten Petersen <karsten.petersen@hrz.tu-chemnitz.de>
    Etan Reisner <deryni@eden.rutgers.edu>
    Albert Chin <china@thewrittenword.com>

%package sqlite
License:        GPL v2 or later
Summary:        SQLite backend for jabberd
Group:          Productivity/Networking/Other
Requires:       %name = %version

%description sqlite
This package contains the database drivers needed to use SQLite as a
storage and authentication backend for jabberd.



%if %mysql

%package mysql
License:        GPL v2 or later
Summary:        MySQL backend for jabberd
Group:          Productivity/Networking/Other
Requires:       %name = %version

%description mysql
This package contains the database drivers needed to use MySQL as a
storage and authentication backend for jabberd.



%endif

%package pgsql
License:        GPL v2 or later
Summary:        PostgreSQL backend for jabberd2
Group:          Productivity/Networking/Other
Requires:       %name = %version

%description pgsql
This package contains the database drivers needed to use PostgreSQL as
a storage and authentication backend for jabberd.



%package db
License:        GPL v2 or later
Summary:        Berkeley DB backend for jabberd2
Group:          Productivity/Networking/Other
Requires:       %name = %version

%description db
This package contains the database drivers needed to use Berkeley DB as
a storage and authentication backend for jabberd.



%package ldap
License:        GPL v2 or later
Summary:        LDAP backend for jabberd2
Group:          Productivity/Networking/Other
Requires:       %name = %version

%description ldap
This package contains the database drivers needed to use LDAP as a
storage and authentication backend for jabberd.



%package pam
License:        GPL v2 or later
Summary:        PAM backend for jabberd2
Group:          Productivity/Networking/Other
Requires:       %name = %version

%description pam
This package contains the driver needed to use PAM as an authentication
backend for jabberd.



%prep
%setup -q
%patch1
%patch2
%patch5
%patch9 -p1
dos2unix tools/db-update.sqlite

%build
CFLAGS="%optflags -fno-strict-aliasing"
%configure \
	--sysconfdir=/etc/jabberd \
	--localstatedir=/var/lib \
	--with-sasl=cyrus \
	--enable-ssl \
%if %mysql
	--enable-mysql \
%else
	--disable-mysql \
%endif
	--enable-pgsql \
	--enable-sqlite \
	--enable-db \
	--enable-ldap \
	--enable-pam \
	--enable-pipe \
	--enable-anon \
	--enable-fs \
	--enable-debug
make

%install
make DESTDIR=%buildroot install-strip
install -d -m750 %buildroot/etc/{init,pam}.d %buildroot/usr/sbin
install %{S:1} %buildroot/etc/init.d/jabberd
install -m0644 %{S:2} %buildroot/etc/pam.d/jabberd
ln -s /etc/init.d/jabberd %buildroot/usr/sbin/rcjabberd
mkdir -p %buildroot/var/lib/jabberd/{db,pid,log,stats,fs}
# .la files are not needed for loadable modules.
rm -f %buildroot%_libdir/%name/*.la

%clean
rm -rf %buildroot

%pre
/usr/sbin/groupadd --system jabber 2>/dev/null ||:
/usr/sbin/useradd --system --gid jabber --comment "Jabber Server" \
	--home /var/lib/jabberd --shell /bin/false jabber 2>/dev/null ||:
exit 0

%preun
%{?stop_on_removal:%stop_on_removal jabberd}
exit 0

%postun
%{?insserv_cleanup:%insserv_cleanup}
exit 0

%files
%defattr (0644, root, root, 0755)
%doc AUTHORS COPYING ChangeLog NEWS README TODO UPGRADE
%doc tools/db-*
%doc /usr/share/man/*/*
%defattr (-, root, root, -)
/etc/init.d/*
/usr/bin/*
/usr/sbin/*
%dir %_libdir/%name
%_libdir/%name/mod_*
%_libdir/%name/authreg_anon.so
%_libdir/%name/authreg_pipe.so
%_libdir/%name/storage_fs.so
%dir /etc/jabberd
%dir /etc/jabberd/templates
%config /etc/jabberd/*.xml.dist
%config /etc/jabberd/*.cfg.dist
%config /etc/jabberd/templates/*.xml.dist
%defattr(0640, root, jabber, 0755)
%config(noreplace) /etc/jabberd/*.xml
%config(noreplace) /etc/jabberd/*.cfg
%config(noreplace) /etc/jabberd/templates/*.xml
%defattr (-, jabber, jabber, -)
/var/lib/jabberd

%files sqlite
%defattr (-, root, root, -)
%_libdir/%name/authreg_sqlite.so
%_libdir/%name/storage_sqlite.so

%if %mysql

%files mysql
%defattr (-, root, root, -)
%_libdir/%name/authreg_mysql.so
%_libdir/%name/storage_mysql.so
%endif

%files pgsql
%defattr (-, root, root, -)
%_libdir/%name/authreg_pgsql.so
%_libdir/%name/storage_pgsql.so

%files db
%defattr (-, root, root, -)
%_libdir/%name/authreg_db.so
%_libdir/%name/storage_db.so

%files ldap
%defattr (-, root, root, -)
%_libdir/%name/authreg_ldap.so
%_libdir/%name/authreg_ldapfull.so
%_libdir/%name/storage_ldapvcard.so

%files pam
%defattr (-, root, root, -)
%_libdir/%name/authreg_pam.so
%config /etc/pam.d/*

%changelog
* Wed Feb  2 2011 ma@suse.de
- Avoid using ASL licenced base64 en/decoding. Use openssl implementation
  instead. (bnc #619101)
* Thu Dec  9 2010 mc@suse.de
- initial release
